@@ -11,7 +11,7 @@ use crate::client::Error;
 use crate::messaging::{
     data::{ChunkRead, DataCmd, DataQuery, QueryResponse},
     section_info::SectionInfoMsg,
-    ClientSigned, MessageId, WireMsg,
+    DataSigned, MessageId, WireMsg,
 };
 use crate::messaging::{DstLocation, MsgKind};
 use crate::types::{Chunk, PrivateChunk, PublicChunk, PublicKey};
@@ -112,7 +112,7 @@ impl Session {
     pub(crate) async fn send_cmd(
         &self,
         cmd: DataCmd,
-        client_signed: ClientSigned,
+        data_signed: DataSigned,
         payload: Bytes,
     ) -> Result<(), Error> {
         let endpoint = self.endpoint()?.clone();
@@ -151,7 +151,7 @@ impl Session {
             name: dst_section_name,
             section_pk,
         };
-        let msg_kind = MsgKind::DataMsg(client_signed);
+        let msg_kind = MsgKind::DataMsg(data_signed);
         let wire_msg = WireMsg::new_msg(msg_id, payload, msg_kind, dst_location)?;
 
         let msg_bytes = wire_msg.serialize()?;
@@ -195,7 +195,7 @@ impl Session {
     pub(crate) async fn send_query(
         &self,
         query: DataQuery,
-        client_signed: ClientSigned,
+        data_signed: DataSigned,
         payload: Bytes,
     ) -> Result<QueryResult, Error> {
         let endpoint = self.endpoint()?.clone();
@@ -219,7 +219,7 @@ impl Session {
             section_pk,
         };
         let msg_id = MessageId::new();
-        let msg_kind = MsgKind::DataMsg(client_signed);
+        let msg_kind = MsgKind::DataMsg(data_signed);
         let wire_msg = WireMsg::new_msg(msg_id, payload, msg_kind, dst_location)?;
 
         let msg_bytes = wire_msg.serialize()?;
@@ -373,14 +373,9 @@ impl Session {
                 // (note, this will overwrite prior errors, so we'll just return whicever was last received)
                 (response @ Some(QueryResponse::GetChunk(Err(_))), Some(_))
                 | (response @ Some(QueryResponse::GetRegister(Err(_))), None)
-                | (response @ Some(QueryResponse::GetSequence(Err(_))), None)
                 | (response @ Some(QueryResponse::GetRegisterPolicy(Err(_))), None)
                 | (response @ Some(QueryResponse::GetRegisterOwner(Err(_))), None)
-                | (response @ Some(QueryResponse::GetRegisterUserPermissions(Err(_))), None)
-                | (response @ Some(QueryResponse::GetSequenceLastEntry(Err(_))), None)
-                | (response @ Some(QueryResponse::GetSequencePrivatePolicy(Err(_))), None)
-                | (response @ Some(QueryResponse::GetSequencePublicPolicy(Err(_))), None)
-                | (response @ Some(QueryResponse::GetSequenceRange(Err(_))), None) => {
+                | (response @ Some(QueryResponse::GetRegisterUserPermissions(Err(_))), None) => {
                     debug!("QueryResponse error received (but may be overridden by a non-error reponse from another elder): {:#?}", &response);
                     error_response = response;
                     responses_discarded += 1;
