@@ -11,21 +11,20 @@ use async_recursion::async_recursion;
 use dashmap::DashSet;
 use futures::future::join_all;
 use std::path::{Path, PathBuf};
-use std::sync::Arc;
 use tokio::fs;
 
 #[derive(Clone, Debug)]
 pub(crate) struct UsedSpace {
     /// the maximum (inclusive) allocated space for storage
     max_capacity: u64,
-    dirs: Arc<DashSet<PathBuf>>,
+    dirs: DashSet<PathBuf>,
 }
 
 impl UsedSpace {
     pub(crate) fn new(max_capacity: u64) -> Self {
         Self {
             max_capacity,
-            dirs: Arc::new(DashSet::new()),
+            dirs: DashSet::new(),
         }
     }
 
