@@ -11,9 +11,9 @@ use crate::messaging::{
         ChunkRead, ChunkWrite, CmdError, DataCmd as NodeDataCmd, DataExchange,
         DataQuery as NodeDataQuery, Error, Result,
     },
-    ClientSigned, EndUser,
+    DataSigned, EndUser,
 };
-use crate::types::{Chunk, ChunkAddress, PublicKey, SectionElders, Signature};
+use crate::types::{Chunk, ChunkAddress, PublicKey, Signature};
 use serde::{Deserialize, Serialize};
 use xor_name::XorName;
 
@@ -25,8 +25,8 @@ pub enum NodeCmd {
     Metadata {
         /// The contianed command
         cmd: NodeDataCmd,
-        /// Client pk and signature
-        client_signed: ClientSigned,
+        /// Requester pk and signature
+        data_signed: DataSigned,
         /// Message source
         origin: EndUser,
     },
@@ -34,8 +34,8 @@ pub enum NodeCmd {
     Chunks {
         /// The contianed command
         cmd: ChunkWrite,
-        /// Client pk and signature
-        client_signed: ClientSigned,
+        /// Requester pk and signature
+        data_signed: DataSigned,
         /// Message source
         origin: EndUser,
     },
@@ -94,7 +94,7 @@ pub enum NodeQuery {
         /// The actual query message
         query: NodeDataQuery,
         /// Client signature
-        client_signed: ClientSigned,
+        data_signed: DataSigned,
         /// The user that has initiated this query
         origin: EndUser,
     },
@@ -105,45 +105,12 @@ pub enum NodeQuery {
         /// The user that has initiated this query
         origin: EndUser,
     },
-    /// Related to the running of a node
-    System(NodeSystemQuery),
-}
-
-///
-#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeSystemQuery {
-    /// On Elder change, all Elders need to query
-    /// network for the new wallet's replicas' public key set
-    GetSectionElders,
-    /// Acquire the chunk from current holders for replication.
-    /// providing the address of the chunk to be replicated.
-    GetChunk(ChunkAddress),
-}
-
-///
-#[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeSystemQueryResponse {
-    /// On Elder change, all Elders need to query
-    /// network for the new wallet's replicas' public key set
-    GetSectionElders(SectionElders),
-    /// Respond elders with the requested chunk for replication
-    GetChunk(Chunk),
 }
 
 ///
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug, Eq, PartialEq, Clone, Serialize, Deserialize)]
 pub enum NodeQueryResponse {
-    ///
-    Data(NodeDataQueryResponse),
-    ///
-    System(NodeSystemQueryResponse),
-}
-
-///
-#[allow(clippy::large_enum_variant)]
-#[derive(Debug, Hash, Eq, PartialEq, Clone, Serialize, Deserialize)]
-pub enum NodeDataQueryResponse {
     /// Elder to Adult Get.
     GetChunk(Result<Chunk>),
 }
