@@ -9,11 +9,8 @@
 use super::{Mapping, MsgContext};
 use crate::messaging::{
     data::{DataCmd, DataMsg, ProcessMsg, QueryResponse},
-    node::{
-        NodeCmd, NodeDataQueryResponse, NodeMsg, NodeQuery, NodeQueryResponse, NodeSystemCmd,
-        NodeSystemQuery,
-    },
-    ClientAuthority, ClientSigned, DstLocation, MessageId, SrcLocation, WireMsg,
+    node::{NodeCmd, NodeMsg, NodeQuery, NodeQueryResponse, NodeSystemCmd},
+    DataAuthority, DataSigned, DstLocation, MessageId, SrcLocation, WireMsg,
 };
 use crate::node::{
     error::convert_to_error_message,
@@ -78,19 +75,19 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
         // ------ metadata ------
         MessageReceived::NodeQuery(NodeQuery::Metadata {
             query,
-            client_signed,
+            data_signed,
             origin: query_origin,
         }) => {
             match verify_data_authority(
                 msg_id,
                 origin,
-                client_signed,
+                data_signed,
                 ProcessMsg::Query(query.clone()),
             ) {
-                Ok(client_auth) => NodeDuty::ProcessRead {
+                Ok(data_auth) => NodeDuty::ProcessRead {
                     query,
                     msg_id,
-                    client_auth,
+                    data_auth,
                     origin: query_origin,
                 },
                 Err(duty) => duty,
@@ -98,15 +95,14 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
         }
         MessageReceived::NodeCmd(NodeCmd::Metadata {
             cmd,
-            client_signed,
+            data_signed,
             origin: cmd_origin,
         }) => {
-            match verify_data_authority(msg_id, origin, client_signed, ProcessMsg::Cmd(cmd.clone()))
-            {
-                Ok(client_auth) => NodeDuty::ProcessWrite {
+            match verify_data_authority(msg_id, origin, data_signed, ProcessMsg::Cmd(cmd.clone())) {
+                Ok(data_auth) => NodeDuty::ProcessWrite {
                     cmd,
                     msg_id,
-                    client_auth,
+                    data_auth,
                     origin: cmd_origin,
                 },
                 Err(duty) => duty,
@@ -119,18 +115,18 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
             msg_id,
         },
         MessageReceived::NodeCmd(NodeCmd::Chunks {
-            cmd, client_signed, ..
+            cmd, data_signed, ..
         }) => {
             match verify_data_authority(
                 msg_id,
                 origin,
-                client_signed,
+                data_signed,
                 ProcessMsg::Cmd(DataCmd::Chunk(cmd.clone())),
             ) {
-                Ok(client_auth) => NodeDuty::WriteChunk {
+                Ok(data_auth) => NodeDuty::WriteChunk {
                     write: cmd,
                     msg_id,
-                    client_auth,
+                    data_auth,
                 },
                 Err(duty) => duty,
             }
@@ -142,10 +138,6 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
         MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::RepublishChunk(chunk))) => {
             NodeDuty::ProcessRepublish { chunk, msg_id }
         }
-        // Aggregated by us, for security
-        MessageReceived::NodeQuery(NodeQuery::System(NodeSystemQuery::GetSectionElders)) => {
-            NodeDuty::GetSectionElders { msg_id, origin }
-        }
         //
         // ------ system cmd ------
         MessageReceived::NodeCmd(NodeCmd::System(NodeSystemCmd::StorageFull {
@@ -153,7 +145,7 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
         })) => NodeDuty::IncrementFullNodeCount { node_id },
         // --- Adult Operation response ---
         MessageReceived::NodeQueryResponse {
-            response: NodeQueryResponse::Data(NodeDataQueryResponse::GetChunk(res)),
+            response: NodeQueryResponse::GetChunk(res),
             correlation_id,
         } => NodeDuty::RecordAdultReadLiveness {
             response: QueryResponse::GetChunk(res),
@@ -172,11 +164,11 @@ fn match_node_msg(msg_id: MessageId, msg: MessageReceived, origin: SrcLocation)
 fn verify_data_authority(
     msg_id: MessageId,
     origin: SrcLocation,
-    client_signed: ClientSigned,
+    data_signed: DataSigned,
     msg: ProcessMsg,
-) -> Result<ClientAuthority, NodeDuty> {
+) -> Result<DataAuthority, NodeDuty> {
     WireMsg::serialize_msg_payload(&DataMsg::Process(msg))
-        .and_then(|payload| client_signed.verify(&payload))
+        .and_then(|payload| data_signed.verify(&payload))
         .map_err(|error| send_error(msg_id, origin, Error::Message(error), false))
 }
 
