@@ -10,11 +10,12 @@ use crate::btree_set;
 use crate::messaging::{
     data::{ChunkDataExchange, ChunkRead, ChunkWrite, CmdError, QueryResponse},
     node::{NodeCmd, NodeMsg, NodeQuery, NodeSystemCmd},
-    ClientAuthority, EndUser, MessageId,
+    DataAuthority, EndUser, MessageId,
 };
 use crate::node::{
     capacity::{Capacity, CHUNK_COPY_COUNT},
     error::convert_to_error_message,
+    network::Network,
     node_ops::{NodeDuties, NodeDuty},
     Error, Result,
 };
@@ -30,6 +31,7 @@ use xor_name::XorName;
 
 use super::{
     adult_liveness::AdultLiveness, build_client_error_response, build_client_query_response,
+    build_forward_query_response,
 };
 
 /// Operations over the data type Blob.
@@ -73,13 +75,13 @@ impl ChunkRecords {
         &self,
         write: ChunkWrite,
         msg_id: MessageId,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
         use ChunkWrite::*;
         match write {
-            New(data) => self.store(data, msg_id, client_auth, origin).await,
-            DeletePrivate(address) => self.delete(address, client_auth, origin).await,
+            New(data) => self.store(data, msg_id, data_auth, origin).await,
+            DeletePrivate(address) => self.delete(address, data_auth, origin).await,
         }
     }
 
@@ -108,10 +110,10 @@ impl ChunkRecords {
         &self,
         chunk: Chunk,
         msg_id: MessageId,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
-        if let Err(error) = validate_chunk_owner(&chunk, client_auth.public_key()) {
+        if let Err(error) = validate_chunk_owner(&chunk, data_auth.public_key()) {
             return self.send_error(error, msg_id, origin).await;
         }
 
@@ -133,7 +135,7 @@ impl ChunkRecords {
             msg_id: MessageId::new(),
             msg: NodeMsg::NodeCmd(NodeCmd::Chunks {
                 cmd: ChunkWrite::New(chunk),
-                client_signed: client_auth.into(),
+                data_signed: data_auth.into(),
                 origin,
             }),
             targets: target_holders,
@@ -147,6 +149,7 @@ impl ChunkRecords {
         correlation_id: MessageId,
         response: QueryResponse,
         src: XorName,
+        network: &Network,
     ) -> Result<NodeDuties> {
         if !matches!(response, QueryResponse::GetChunk(_)) {
             return Err(Error::Logic(format!(
@@ -172,11 +175,40 @@ impl ChunkRecords {
                 // We've already responded already with a success or the returned error is `DataNotFound`
                 // so do nothing
             } else {
-                duties.push(NodeDuty::Send(build_client_query_response(
-                    response,
-                    origin_msg_id,
-                    end_user,
-                )));
+                info!("REMOVED CORRELATION ID: {}", correlation_id);
+                let our_prefix = network.our_prefix().await;
+                // If in same section, i.e. we are the ClientElders, then send response directly.
+                // Otherwise, i.e. we are the DataElders, forwarding using ForwardDataMsg.
+                if our_prefix.matches(&end_user.xorname) {
+                    duties.push(NodeDuty::Send(build_client_query_response(
+                        response,
+                        origin_msg_id,
+                        end_user,
+                    )));
+                } else {
+                    let section_pk_option = if let Ok(section_pk) =
+                        network.get_section_pk_by_name(&end_user.xorname).await
+                    {
+                        section_pk.bls()
+                    } else {
+                        None
+                    };
+                    let section_pk = if let Some(section_pk) = section_pk_option {
+                        section_pk
+                    } else {
+                        error!(
+                            "Cannot get EndUser({:?})'s section's section key.",
+                            end_user.xorname
+                        );
+                        return Err(Error::NoSectionPublicKey);
+                    };
+                    duties.push(NodeDuty::Send(build_forward_query_response(
+                        response,
+                        origin_msg_id,
+                        end_user,
+                        section_pk,
+                    )?));
+                }
             }
         } else if response.is_success() {
             info!(
@@ -215,7 +247,7 @@ impl ChunkRecords {
     async fn delete(
         &self,
         address: ChunkAddress,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
         let targets = self.capacity.get_chunk_holder_adults(address.name()).await;
@@ -224,7 +256,7 @@ impl ChunkRecords {
             msg_id: MessageId::new(),
             msg: NodeMsg::NodeCmd(NodeCmd::Chunks {
                 cmd: ChunkWrite::DeletePrivate(address),
-                client_signed: client_auth.into(),
+                data_signed: data_auth.into(),
                 origin,
             }),
             targets,
