@@ -6,13 +6,10 @@
 // KIND, either express or implied. Please review the Licences for the specific language governing
 // permissions and limitations relating to use of the SAFE Network Software.
 
-use super::{
-    chunk_records::ChunkRecords, register_storage::RegisterStorage,
-    sequence_storage::SequenceStorage,
-};
+use super::{chunk_records::ChunkRecords, register_storage::RegisterStorage};
 use crate::messaging::{
     data::{DataCmd, DataExchange, DataQuery},
-    ClientAuthority, EndUser, MessageId,
+    DataAuthority, EndUser, MessageId,
 };
 use crate::node::{node_ops::NodeDuty, Error, Result};
 use crate::routing::Prefix;
@@ -23,19 +20,13 @@ use tracing::info;
 /// that are only managed at Elders.
 pub(super) struct ElderStores {
     chunk_records: ChunkRecords,
-    sequence_storage: SequenceStorage,
     register_storage: RegisterStorage,
 }
 
 impl ElderStores {
-    pub(super) fn new(
-        chunk_records: ChunkRecords,
-        sequence_storage: SequenceStorage,
-        register_storage: RegisterStorage,
-    ) -> Self {
+    pub(super) fn new(chunk_records: ChunkRecords, register_storage: RegisterStorage) -> Self {
         Self {
             chunk_records,
-            sequence_storage,
             register_storage,
         }
     }
@@ -49,11 +40,6 @@ impl ElderStores {
     ) -> Result<NodeDuty> {
         match &query {
             DataQuery::Blob(read) => self.chunk_records.read(read, msg_id, origin).await,
-            DataQuery::Sequence(read) => {
-                self.sequence_storage
-                    .read(read, msg_id, requester, origin)
-                    .await
-            }
             DataQuery::Register(read) => {
                 self.register_storage
                     .read(read, msg_id, requester, origin)
@@ -66,7 +52,7 @@ impl ElderStores {
         &mut self,
         cmd: DataCmd,
         msg_id: MessageId,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
         info!("Writing Data");
@@ -74,19 +60,13 @@ impl ElderStores {
             DataCmd::Chunk(write) => {
                 info!("Writing Blob");
                 self.chunk_records
-                    .write(write, msg_id, client_auth, origin)
-                    .await
-            }
-            DataCmd::Sequence(write) => {
-                info!("Writing Sequence");
-                self.sequence_storage
-                    .write(msg_id, origin, write, client_auth)
+                    .write(write, msg_id, data_auth, origin)
                     .await
             }
             DataCmd::Register(write) => {
                 info!("Writing Register");
                 self.register_storage
-                    .write(msg_id, origin, write, client_auth)
+                    .write(msg_id, origin, write, data_auth)
                     .await
             }
         }
@@ -101,19 +81,16 @@ impl ElderStores {
         // Prepare chunk_records, map and sequence data
         let chunk_data = self.chunk_records.get_data_of(prefix).await;
         let reg_data = self.register_storage.get_data_of(prefix).await?;
-        let seq_data = self.sequence_storage.get_data_of(prefix).await?;
 
         Ok(DataExchange {
             chunk_data,
             reg_data,
-            seq_data,
         })
     }
 
     pub(super) async fn update(&mut self, data: DataExchange) -> Result<(), Error> {
         // todo: all this can be done in parallel
         self.register_storage.update(data.reg_data).await?;
-        self.sequence_storage.update(data.seq_data).await?;
         self.chunk_records.update(data.chunk_data).await;
         Ok(())
     }
