@@ -11,24 +11,27 @@ pub(crate) mod adult_reader;
 mod chunk_records;
 mod elder_stores;
 mod register_storage;
-mod sequence_storage;
 
 use crate::dbs::UsedSpace;
 use crate::messaging::{
     data::{CmdError, DataCmd, DataExchange, DataMsg, DataQuery, ProcessMsg, QueryResponse},
-    ClientAuthority, ClientSigned, DstLocation, EndUser, MessageId, WireMsg,
+    node::NodeMsg,
+    DataAuthority, DataSigned, DstLocation, EndUser, MessageId, WireMsg,
 };
+
 use crate::node::{
     capacity::Capacity,
+    network::Network,
     node_ops::{MsgType, NodeDuties, NodeDuty, OutgoingMsg},
     Error, Result,
 };
 use crate::routing::Prefix;
-use crate::types::{Chunk, PublicKey};
+use crate::types::{Chunk, Keypair, PublicKey};
+use bls::PublicKey as BlsPublicKey;
 use chunk_records::ChunkRecords;
 use elder_stores::ElderStores;
+use rand::rngs::OsRng;
 use register_storage::RegisterStorage;
-use sequence_storage::SequenceStorage;
 use std::{
     collections::BTreeSet,
     fmt::{self, Display, Formatter},
@@ -53,9 +56,8 @@ impl Metadata {
         capacity: Capacity,
     ) -> Result<Self> {
         let chunk_records = ChunkRecords::new(capacity);
-        let sequence_storage = SequenceStorage::new(path, used_space.max_capacity()); // to be removed so we don't care to implement this
-        let register_storage = RegisterStorage::new(path, used_space);
-        let elder_stores = ElderStores::new(chunk_records, sequence_storage, register_storage);
+        let register_storage = RegisterStorage::new(path, used_space)?;
+        let elder_stores = ElderStores::new(chunk_records, register_storage);
         Ok(Self { elder_stores })
     }
 
@@ -77,10 +79,11 @@ impl Metadata {
         correlation_id: MessageId,
         result: QueryResponse,
         src: XorName,
+        network: &Network,
     ) -> Result<NodeDuties> {
         self.elder_stores
             .chunk_records()
-            .record_adult_read_liveness(correlation_id, result, src)
+            .record_adult_read_liveness(correlation_id, result, src, network)
             .await
     }
 
@@ -96,10 +99,10 @@ impl Metadata {
         &mut self,
         cmd: DataCmd,
         id: MessageId,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
         origin: EndUser,
     ) -> Result<NodeDuty> {
-        self.elder_stores.write(cmd, id, client_auth, origin).await
+        self.elder_stores.write(cmd, id, data_auth, origin).await
     }
 
     /// Adds a given node to the list of full nodes.
@@ -149,6 +152,42 @@ fn build_client_query_response(
     }
 }
 
+fn build_forward_query_response(
+    response: QueryResponse,
+    correlation_id: MessageId,
+    origin: EndUser,
+    section_pk: BlsPublicKey,
+) -> Result<OutgoingMsg> {
+    let msg = DataMsg::Process(ProcessMsg::QueryResponse {
+        response,
+        correlation_id,
+    });
+
+    let mut rng = OsRng;
+    let keypair = Keypair::new_ed25519(&mut rng);
+    let payload = WireMsg::serialize_msg_payload(&msg)?;
+    let signature = keypair.sign(&payload);
+
+    let data_signed = DataSigned {
+        public_key: keypair.public_key(),
+        signature,
+    };
+
+    Ok(OutgoingMsg {
+        id: MessageId::in_response_to(&correlation_id),
+        msg: MsgType::Node(NodeMsg::ForwardDataMsg {
+            msg,
+            user: origin,
+            data_signed,
+        }),
+        dst: DstLocation::Section {
+            name: origin.xorname,
+            section_pk,
+        },
+        aggregation: false,
+    })
+}
+
 fn build_client_error_response(error: CmdError, msg_id: MessageId, origin: EndUser) -> OutgoingMsg {
     OutgoingMsg {
         id: MessageId::in_response_to(&msg_id),
@@ -162,8 +201,8 @@ fn build_client_error_response(error: CmdError, msg_id: MessageId, origin: EndUs
 }
 
 // TODO: verify earlier so that this isn't needed
-fn verify_op(client_signed: ClientSigned, cmd: DataCmd) -> Result<ClientAuthority> {
+fn verify_op(data_signed: DataSigned, cmd: DataCmd) -> Result<DataAuthority> {
     let message = DataMsg::Process(ProcessMsg::Cmd(cmd));
     let payload = WireMsg::serialize_msg_payload(&message)?;
-    Ok(client_signed.verify(&payload)?)
+    Ok(data_signed.verify(&payload)?)
 }
