@@ -7,7 +7,7 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use super::{build_client_error_response, build_client_query_response};
-use crate::dbs::{EventStore, UsedSpace};
+use crate::dbs::{RegisterCmdEventStore, UsedSpace};
 use crate::node::{error::convert_to_error_message, node_ops::NodeDuty, Error, Result};
 use crate::types::{
     register::{Action, Address, Register, User},
@@ -19,11 +19,12 @@ use crate::{
             CmdError, DataCmd, QueryResponse, RegisterCmd, RegisterDataExchange, RegisterRead,
             RegisterWrite,
         },
-        ClientAuthority, EndUser, MessageId,
+        DataAuthority, EndUser, MessageId,
     },
     types::DataAddress,
 };
 use dashmap::DashMap;
+use sled::Db;
 use std::{
     collections::BTreeMap,
     fmt::{self, Display, Formatter},
@@ -32,26 +33,39 @@ use std::{
 use tracing::info;
 use xor_name::{Prefix, XorName};
 
+const DATABASE_NAME: &str = "register.db";
+
 /// Operations over the data type Register.
+#[derive(Clone)]
 pub(super) struct RegisterStorage {
     path: PathBuf,
     used_space: UsedSpace,
     registers: DashMap<XorName, Option<StateEntry>>,
+    db: Db,
 }
 
+#[derive(Clone)]
 struct StateEntry {
     state: Register,
-    db: EventStore<RegisterCmd>,
+    store: RegisterCmdEventStore,
 }
 
 impl RegisterStorage {
-    pub(super) fn new(path: &Path, used_space: UsedSpace) -> Self {
+    pub(super) fn new(path: &Path, used_space: UsedSpace) -> Result<Self> {
         used_space.add_dir(path);
-        Self {
+        let db_dir = path.join("db").join(DATABASE_NAME.to_string());
+
+        let db = sled::open(db_dir).map_err(|error| {
+            trace!("Sled Error: {:?}", error);
+            Error::UnableToCreateRegisterDb
+        })?;
+
+        Ok(Self {
             path: path.to_path_buf(),
             used_space,
             registers: DashMap::new(),
-        }
+            db,
+        })
     }
 
     /// --- Synching ---
@@ -64,7 +78,7 @@ impl RegisterStorage {
             let (key, cache) = entry.pair();
             if let Some(entry) = cache {
                 if prefix.matches(entry.state.name()) {
-                    let _ = the_data.insert(*key, entry.db.get_all());
+                    let _ = the_data.insert(*key, entry.store.get_all()?);
                 }
             } else {
             }
@@ -82,31 +96,12 @@ impl RegisterStorage {
         // todo: make outer loop parallel
         for (_, history) in data {
             for op in history {
-                let client_auth =
+                let data_auth =
                     super::verify_op(op.client_sig.clone(), DataCmd::Register(op.write.clone()))?;
-                let _ = self.apply(op, client_auth).await?;
+                let _ = self.apply(op, data_auth).await?;
             }
         }
 
-        // let instance = Arc::new(self);
-
-        // let handles = data.iter().map(|(_, history)| {
-        //     let store = instance.clone();
-        //     tokio::task::spawn(async {
-        //         for op in history {
-        //             let _ = store.apply(*op).await?;
-        //             //let _ = self.apply(*op).await?;
-        //         }
-        //         Ok::<_, Error>(())
-        //     })
-        // });
-
-        // join_all(handles)
-        //     .await
-        //     .iter()
-        //     .flatten()
-        //     .for_each(|e| error!("{:?}", e));
-
         Ok(())
     }
 
@@ -117,7 +112,7 @@ impl RegisterStorage {
         msg_id: MessageId,
         origin: EndUser,
         write: RegisterWrite,
-        client_auth: ClientAuthority,
+        data_auth: DataAuthority,
     ) -> Result<NodeDuty> {
         let required_space = std::mem::size_of::<RegisterCmd>() as u64;
         if !self.used_space.can_consume(required_space).await {
@@ -125,13 +120,13 @@ impl RegisterStorage {
         }
         let op = RegisterCmd {
             write,
-            client_sig: client_auth.to_signed(),
+            client_sig: data_auth.to_signed(),
         };
-        let write_result = self.apply(op, client_auth).await;
+        let write_result = self.apply(op, data_auth).await;
         self.ok_or_error(write_result, msg_id, origin).await
     }
 
-    async fn apply(&self, op: RegisterCmd, client_auth: ClientAuthority) -> Result<()> {
+    async fn apply(&self, op: RegisterCmd, data_auth: DataAuthority) -> Result<()> {
         let RegisterCmd { write, .. } = op.clone();
 
         let address = *write.address();
@@ -143,22 +138,19 @@ impl RegisterStorage {
                 if self.registers.contains_key(&key) {
                     return Err(Error::DataExists);
                 }
-                let mut db = load_db(key, self.path.as_path()).await?;
-                let _ = db.append(op)?;
+                let mut store = self.load_store(key)?;
+                let _ = store.append(op)?;
                 let _ = self
                     .registers
-                    .insert(key, Some(StateEntry { state: map, db }));
+                    .insert(key, Some(StateEntry { state: map, store }));
                 Ok(())
             }
             Delete(_) => {
                 let result = match self.registers.get_mut(&key) {
                     None => {
-                        if let Ok(db) = load_db(key, self.path.as_path()).await {
-                            info!("Deleting Register");
-                            db.as_deletable().delete().await.map_err(Error::from)
-                        } else {
-                            Ok(())
-                        }
+                        info!("Attempting to delete register if it exists");
+                        let _ = self.db.drop_tree(key)?;
+                        Ok(())
                     }
                     Some(mut entry) => {
                         let (_, cache) = entry.pair_mut();
@@ -170,15 +162,17 @@ impl RegisterStorage {
                             }
                             // TODO - Register::check_permission() doesn't support Delete yet in safe-nd
                             // register.check_permission(action, Some(client_sig.public_key))?;
-                            if client_auth.public_key() != &entry.state.owner() {
-                                Err(Error::InvalidOwner(*client_auth.public_key()))
+                            if data_auth.public_key() != &entry.state.owner() {
+                                Err(Error::InvalidOwner(*data_auth.public_key()))
                             } else {
                                 info!("Deleting Register");
-                                entry.db.as_deletable().delete().await.map_err(Error::from)
+                                let _ = self.db.drop_tree(key)?;
+                                Ok(())
                             }
-                        } else if let Ok(db) = load_db(key, self.path.as_path()).await {
+                        } else if self.load_store(key).is_ok() {
                             info!("Deleting Register");
-                            db.as_deletable().delete().await.map_err(Error::from)
+                            let _ = self.db.drop_tree(key)?;
+                            Ok(())
                         } else {
                             Ok(())
                         }
@@ -200,10 +194,10 @@ impl RegisterStorage {
                     cached_entry
                 } else {
                     // read from disk
-                    let db = load_db(key, self.path.as_path()).await?;
+                    let store = self.load_store(key)?;
                     let mut reg = None;
                     // apply all ops
-                    for op in db.get_all() {
+                    for op in store.get_all()? {
                         // first op shall be New
                         if let New(register) = op.write {
                             reg = Some(register);
@@ -217,7 +211,7 @@ impl RegisterStorage {
                     let new_entry = reg
                         .take()
                         .ok_or(Error::NoSuchData(DataAddress::Register(address)))
-                        .map(|state| StateEntry { state, db })?;
+                        .map(|state| StateEntry { state, store })?;
 
                     let _ = cache.replace(new_entry);
 
@@ -231,11 +225,11 @@ impl RegisterStorage {
                 info!("Editing Register");
                 entry
                     .state
-                    .check_permissions(Action::Write, Some(*client_auth.public_key()))?;
+                    .check_permissions(Action::Write, Some(*data_auth.public_key()))?;
                 let result = entry.state.apply_op(reg_op).map_err(Error::NetworkData);
 
                 if result.is_ok() {
-                    entry.db.append(op)?;
+                    entry.store.append(op)?;
                     info!("Editing Register SUCCESSFUL!");
                 } else {
                     info!("Editing Register FAILED!");
@@ -429,6 +423,11 @@ impl RegisterStorage {
             origin,
         )))
     }
+
+    /// Load a register cmd event store
+    fn load_store(&self, id: XorName) -> Result<RegisterCmdEventStore> {
+        RegisterCmdEventStore::new(id, self.db.clone()).map_err(Error::from)
+    }
 }
 
 fn to_id(address: &Address) -> Result<XorName> {
@@ -437,13 +436,6 @@ fn to_id(address: &Address) -> Result<XorName> {
         .as_bytes()]))
 }
 
-async fn load_db(id: XorName, path: &Path) -> Result<EventStore<RegisterCmd>> {
-    let db_dir = path.join("db").join("register".to_string());
-    EventStore::new(id, db_dir.as_path())
-        .await
-        .map_err(Error::from)
-}
-
 impl Display for RegisterStorage {
     fn fmt(&self, formatter: &mut Formatter) -> fmt::Result {
         write!(formatter, "RegisterStorage")
