@@ -99,19 +99,12 @@ impl Core {
             }
             MessageType::Client {
                 msg_id,
-                client_auth,
+                data_auth,
                 msg,
                 dst_location,
             } => {
-                self.handle_end_user_message(
-                    sender,
-                    msg_id,
-                    client_auth,
-                    msg,
-                    dst_location,
-                    payload,
-                )
-                .await
+                self.handle_end_user_message(sender, msg_id, data_auth, msg, dst_location, payload)
+                    .await
             }
         }
     }
@@ -208,7 +201,7 @@ impl Core {
             NodeMsg::ForwardDataMsg {
                 msg,
                 user,
-                client_signed,
+                data_signed,
             } => {
                 // If elder, always handle Forward
                 if self.is_not_elder() {
@@ -219,9 +212,9 @@ impl Core {
                 // TODO: preserve the source bytes so we don't need to serialize again here, or else
                 // verify earlier.
                 let payload = WireMsg::serialize_msg_payload(&msg)?;
-                let client_auth = client_signed.verify(&payload)?;
+                let data_auth = data_signed.verify(&payload)?;
 
-                self.handle_client_msg_received(msg_id, msg, user, client_auth)
+                self.handle_client_msg_received(msg_id, msg, user, data_auth)
                     .await
             }
             NodeMsg::SectionKnowledge {
