@@ -17,8 +17,6 @@ pub mod utils;
 mod chunk;
 mod errors;
 mod keys;
-mod section;
-mod sequence;
 mod token;
 
 pub use chunk::{
@@ -34,18 +32,6 @@ pub use keys::{
     signature::{Signature, SignatureShare},
 };
 pub use register::Address as RegisterAddress;
-pub use section::SectionElders;
-pub use sequence::{
-    metadata::{
-        Action as SequenceAction, Address as SequenceAddress, Entries as SequenceEntries,
-        Entry as SequenceEntry, Index as SequenceIndex, Kind as SequenceKind,
-        Permissions as SequencePermissions, Policy as SequencePolicy,
-        PrivatePermissions as SequencePrivatePermissions, PrivatePolicy as SequencePrivatePolicy,
-        PublicPermissions as SequencePublicPermissions, PublicPolicy as SequencePublicPolicy,
-        User as SequenceUser,
-    },
-    Data as Sequence, DataOp as SequenceOp, PrivateSeqData, PublicSeqData,
-};
 pub use token::Token;
 
 use register::Register;
@@ -58,8 +44,6 @@ use xor_name::XorName;
 pub enum Data {
     /// Chunk.
     Chunk(Chunk),
-    /// Sequence.
-    Sequence(Sequence),
     /// Register.
     Register(Register),
 }
@@ -69,8 +53,6 @@ pub enum Data {
 pub enum DataAddress {
     /// Chunk Address
     Chunk(ChunkAddress),
-    /// Sequence Address
-    Sequence(SequenceAddress),
     /// Register Address
     Register(RegisterAddress),
 }
@@ -80,7 +62,6 @@ impl Data {
     pub fn is_public(&self) -> bool {
         match *self {
             Self::Chunk(ref chunk) => chunk.is_public(),
-            Self::Sequence(ref sequence) => sequence.is_public(),
             Self::Register(ref register) => register.is_public(),
         }
     }
@@ -97,12 +78,6 @@ impl From<Chunk> for Data {
     }
 }
 
-impl From<Sequence> for Data {
-    fn from(data: Sequence) -> Self {
-        Self::Sequence(data)
-    }
-}
-
 impl From<Register> for Data {
     fn from(data: Register) -> Self {
         Self::Register(data)
